@@ -25,10 +25,10 @@ export interface LinkOutSuggestionOptions {
   name: string;
 
   /**
-   * String URL to open.
+   * URL action when clicked.
    * @public
    */
-  url: string;
+  openUrlAction: Api.GoogleActionsV2UiElementsOpenUrlAction;
 }
 
 /**
@@ -39,13 +39,14 @@ export interface LinkOutSuggestionOptions {
 export interface LinkOutSuggestion
   extends Api.GoogleActionsV2UiElementsLinkOutSuggestion {}
 export class LinkOutSuggestion
-  implements Api.GoogleActionsV2UiElementsLinkOutSuggestion {
+  implements Api.GoogleActionsV2UiElementsLinkOutSuggestion
+{
   /**
    * @param options LinkOutSuggestion options
    * @public
    */
   constructor(options: LinkOutSuggestionOptions) {
     this.destinationName = options.name;
-    this.url = options.url;
+    this.openUrlAction = options.openUrlAction;
   }
 }
